OC.L10N.register(
    "activity",
    {
    "Activity" : "Aktivität",
    "Personal activity feed for %s" : "Persönlicher Feed der Aktivitäten für %s",
    "Your feed URL is invalid" : "Ihre Feed-URL ist ungültig",
    "Your settings have been updated." : "Ihre Einstellungen wurden aktualisiert.",
    "Mail" : "Mail",
    "Stream" : "Stream",
    "Activities" : "Aktivitäten",
    "Error loading activities" : "Fehler beim Laden von Aktivitäten.",
    "No activities" : "Keine Aktivitäten.",
    ", " : ", ",
    "{parameterList} and {lastParameter}" : "{parameterList} und {lastParameter}",
    "_{parameterList} and {linkStart}%n more{linkEnd}_::_{parameterList} and {linkStart}%n more{linkEnd}_" : ["{parameterList} and {linkStart}ein weiterer{linkEnd}","{parameterList} und {linkStart}%n weitere{linkEnd}"],
    "in {directory}" : "in {directory}",
    "This stream will show events like additions, changes & shares" : "Dieser Stream zeigt Ereignisse wie Hinzugekommenes, Änderungen und Freigaben an",
    "There are no events for this filter" : "Keine Ereignisse für diesen Filter vorhanden",
    "Today" : "Heute",
    "Yesterday" : "Gestern",
    "\"remote user\"" : "„Entfernter Benutzer“",
    "Activity notification" : "Benachrichtigung über die Aktivitäten",
    "All Activities" : "Alle Aktivitäten",
    "Activities by you" : "Ihre Aktivitäten",
    "Activities by others" : "Aktivitäten von Anderen",
    "%s and %s" : "%s und %s",
    "Hello %s," : "Hallo %s,",
    "You are receiving this email because the following things happened at %s" : "Sie erhalten diese E-Mail, da folgende Dinge auf %s geschehen sind",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* und %n weiterer","* und %n weitere"],
    "List your own actions in the stream" : "Ihre eigenen Aktivitäten im Stream auflisten",
    "Notify about your own actions via email" : "Über Ihre eigenen Aktivitäten via E-Mail benachrichtigen",
    "You need to set up your email address before you can receive notification emails." : "Bevor Sie E-Mail-Benachrichtigungen empfangen können, müssen Sie Ihre E-Mail-Adresse einrichten.",
    "Send emails:" : "E-Mails senden:",
    "Hourly" : "stündlich",
    "Daily" : "täglich",
    "Weekly" : "wöchentlich",
    "Activity feed" : "Feed der Aktivitäten",
    "Enable RSS feed" : "RSS-Feed aktivieren",
    "No activity yet" : "Bislang keine Aktivitäten",
    "No more events to load" : "Keine weiteren Ereignisse zu Laden",
    "Files" : "Dateien"
},
"nplurals=2; plural=(n != 1);");
